# Pet Path Tester
import requests
import json
import pytest
import schemathesis

_BASE_URL = "https://petstore3.swagger.io/api/v3/"
# _BASE_URL="https://api-sit.mars-de.dev.dicelab.net:8443/api/mars-de/av"
_API_KEY = ""


class TestPetStoreSt:
    schema = schemathesis.from_path('./test_openapi_paths/pet3.json')
    schema.base_url = _BASE_URL

    @pytest.fixture(scope="class")
    def setup_header(self):
        headers = {'accept': 'application/json', 'Content-Type': 'application/json', 'api_key': _API_KEY}
        return headers

    # need to populate:
    def test_findbystatus_get(self, setup_header):
        # response = requests.post(_BASE_URL, headers=setup_header)
        # TO-DO implement response validation
        # print(response.json()
        # TO-DO: implement
        pass

    @schema.parametrize()
    def test_api(case):
        response = case.call()

        print(case)
        print(response)
        print(response.text)
        print("***** ***** *****")

        case.validate_response(response)

    def add_three_st(number):
        return number + 3



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Lisa Mak",
    author_email='lmak@mitre.org',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Tests the paths in an openapi spec",
    entry_points={
        'console_scripts': [
            'test_openapi_paths=test_openapi_paths.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='test_openapi_paths',
    name='test_openapi_paths',
    packages=find_packages(include=['test_openapi_paths', 'test_openapi_paths.*']),
    package_data={
        'test_openapi_paths': ['data/*.json'],
   },
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/lmakuser/test_openapi_paths',
    version='0.1.4.1',
    zip_safe=False,
)



import schemathesis


# before moved to data folder
# schema = schemathesis.from_path('./test_openapi_paths/pet3.json')

schema = schemathesis.from_path('../data/pet3.json')
schema.base_url = "https://petstore3.swagger.io/api/v3/"


@schema.parametrize()
def test_api(case):
    response = case.call()

    print(case)
    print(response)
    print(response.text)
    print("***** ***** *****")

    case.validate_response(response)


def add_one(number):
    return number + 1
